package zkp;

import java.awt.Graphics;

import zkp.GamePanel.ShipClass;

/**
 * A middle-sized ship that launches smaller ShuttleShips to attack the PlayerShip
 *
 * @author zsmb
 */
public class ExplorerShip extends EnemyShip {

    private static final long serialVersionUID = 3163391256372932542L;

    private static final int radius = 15; // Class specific radius to set in the
                                          // base class

    private int currentTargetTime; // The next count to reach before spawning a
                                   // ShuttleShip
    private int counter; // A counter to increase every time the ExplorerShip
                         // moves

    /**
     * ExplorerShip ctor
     * 
     * @param gpa the containing GamePanel's interface for communication
     */
    public ExplorerShip(GamePanelAccessProvider gpa) {
        super(gpa, radius);
        randomizeTargetTime(300, 450);
        counter = 0;
        setWord(gpa.getWord(ShipClass.Explorer));
        this.yVelocity = gpa.getUnitSpeed() * 2.0 / 3.0;
    }

    /**
     * Getter function to determine the EnemyShip's type
     * 
     * @return ShipClass.Explorer
     */
    @Override
    public ShipClass getShipClass() {
        return ShipClass.Explorer;
    }

    /**
     * Paints the ExplorerShip on the screen
     * 
     * @param g the Graphics object to use for drawing
     */
    @Override
    public void paint(Graphics g) {
        GFX.circle(g, x, y, radius, 0x6699FFDD);
        paintText(g, -radius, 5);
    }

    /**
     * Generates a new random delay until next spawn
     * 
     * @param minTime the minimum time for the delay
     * @param maxTime the maximum time for the delay
     */
    private void randomizeTargetTime(int minTime, int maxTime) {
        currentTargetTime = Util.getRandomNumber(minTime, maxTime);
    }

    /**
     * Moves the ship ahead, as well as increases timer and spawns a ShuttleShip if needed
     * 
     * @return true if it hit the PlayerShip
     */
    public boolean progress() {
        counter++;
        if (counter == currentTargetTime) {
            counter = 0;
            randomizeTargetTime(300, 600);
            if (gpa.getDistanceLeft(this) >= 150) {
                gpa.requestSpawn(new ShuttleShip(gpa, x, y), this);
            }
        }

        return super.progress();
    }

}
