package zkp;

import java.awt.Graphics;

import zkp.GamePanel.ShipClass;

/**
 * A FighterShip that flies straight until it hits the PlayerShip or goes offscreen
 *
 * @author zsmb
 */
public class FighterShip extends EnemyShip {

    private static final long serialVersionUID = -1442109895498385530L;

    private static final double velocity = 1; // total speed of the FighterShip
                                              // vectorial sum of its x and y
                                              // speeds
    private static final int radius = 4; // Class specific radius to set in the
                                         // base class

    /**
     * FighterShip ctor
     * 
     * @param gpa the containing GamePanel's interface for communication
     * @param x the x position to spawn the FighterShip in
     * @param y the y position to spawn the FighterShip in
     * @param direction the degree to launch the FighterShip in, 0 being straight right,
     *            pi/2 being straight down
     */
    public FighterShip(GamePanelAccessProvider gpa, double x, double y, double direction) {
        super(gpa, radius, x, y);
        setWord(gpa.getWord(ShipClass.Fighter));

        this.xVelocity = Math.cos(direction) * velocity;
        this.yVelocity = -Math.sin(direction) * velocity;
    }

    /**
     * Getter function for the specific type of the EnemyShip
     * 
     * @return ShipClass.Fighter
     */
    @Override
    public ShipClass getShipClass() {
        return ShipClass.Fighter;
    }

    /**
     * Paints the FighterShip on the screen
     * 
     * @param g the Graphics object to use for painting
     */
    @Override
    public void paint(Graphics g) {
        GFX.circle(g, x, y, radius, 0xFF66CCFF);
        paintText(g, -radius, 4);
    }

    /**
     * Advances the FighterShip forward, signals the GamePanel to remove it if it went off
     * screen
     * 
     * @return true if it hit the PlayerShip
     */
    @Override
    public boolean progress() {
        return super.progress();
    }

}
