package zkp;

import java.awt.Graphics;
import java.io.Serializable;

/**
 * Abstract base class for all objects that appear on the screen in the game
 *
 * @author zsmb
 */
abstract public class GameObject implements Serializable {

    private static final long serialVersionUID = 583121688471912466L;

    protected double x; // x position
    protected double y; // y position

    /**
     * Default GameObject ctor
     */
    GameObject() {
        this(0, 0);
    }

    /**
     * GameObject ctor with explicit position information
     * 
     * @param x x position
     * @param y y position
     */
    GameObject(double x, double y) {
        this.x = x;
        this.y = y;
    }

    /**
     * Getter function
     * 
     * @return The GameObject's x position
     */
    public final double getX() {
        return x;
    }

    /**
     * Getter function
     * 
     * @return The GameObject's y position
     */
    public final double getY() {
        return y;
    }

    /**
     * Setter function for the GameObject's coordinates
     * 
     * @param x x position
     * @param y y position
     */
    public void setXY(double x, double y) {
        this.x = x;
        this.y = y;
    }

    /**
     * Paints the GameObject on the screen
     * 
     * @param g the Graphics object to use
     */
    abstract public void paint(Graphics g);

    /**
     * Notifies an object of the passing of one time unit
     * 
     * @return can be used to signal caller, should be false by default
     */
    abstract public boolean progress();

}
