package zkp;

import java.awt.Graphics;

import zkp.GamePanel.ShipClass;

/**
 * The toughest ship of the game, periodically sends out dozens of FighterShips to attack
 * the PlayerShip
 *
 * @author zsmb
 */
public class MotherShip extends EnemyShip {

    private static final long serialVersionUID = -6113791732932308356L;

    private int currentLaunchTime; // number of ticks to wait before next launch
                                   // of FighterShips
    private int counter = 0; // number of ticks already waited

    private static final int radius = 20; // Class specific radius to set in the
                                          // base class

    /**
     * MotherShip ctor
     * 
     * @param gpa the containing GamePanel's interface for communication
     */
    public MotherShip(GamePanelAccessProvider gpa) {
        super(gpa, radius);
        randomizeLaunchTime(400, 600);
        setWord(gpa.getWord(ShipClass.Mothership));
        this.yVelocity = gpa.getUnitSpeed() * 2.0 / 3.0;
    }

    /**
     * Getter function to determine the EnemyShip's type
     * 
     * @return ShipClass.MotherShip
     */
    @Override
    public ShipClass getShipClass() {
        return ShipClass.Mothership;
    }

    /**
     * Paints the MotherShip on the screen
     * 
     * @param g the Graphics object to use for drawing
     */
    @Override
    public void paint(Graphics g) {
        GFX.circle(g, x, y, radius, 0xCC00FFDD);
        paintText(g, -radius, 5);
    }

    /**
     * Generates a new random delay until next attack
     * 
     * @param minTime the minimum time for the delay
     * @param maxTime the maximum time for the delay
     */
    private void randomizeLaunchTime(int minTime, int maxTime) {
        currentLaunchTime = Util.getRandomNumber(minTime, maxTime);
        return;
    }

    /**
     * Moves the ship ahead, as well as increases timer and spawns FighterShips if needed
     * 
     * @return true if it hit the PlayerShip
     */
    public boolean progress() {
        counter += 1;
        if (counter == currentLaunchTime) {
            counter = 0;
            randomizeLaunchTime(400, 800);

            for (double offset = 0; offset <= 1; offset += 0.076) {
                gpa.requestSpawn(
                        new FighterShip(gpa, x, y, -Math.PI * (0.25 + 0.5 * offset)), this);
            }
        }
        return super.progress();
    }

}
