package zkp;

import java.awt.Graphics;

/**
 * A Projectile that can be fired at an EnemyShip
 *
 * @author zsmb
 */
public class Projectile extends GameObject {

    private static final long serialVersionUID = -6662414485198110396L;

    /**
     * Total velocity of the Projectile, absolute value of its velocity vector
     */
    private static double velocity = 30;
    /** Length of the Projectile's path for drawing */
    private static int length = 2;

    private EnemyShip target; // the EnemyShip the Projectile is flying into
    private ShiftRegister<Double> xValues; // previous x positions of the
                                           // Projectile
    private ShiftRegister<Double> yValues; // previous y positions of the
                                           // Projectile

    /**
     * Projectile ctor
     * 
     * @param x x position
     * @param y y position
     * @param targetShip the EnemyShip to shoot the Projectile at
     */
    public Projectile(double x, double y, EnemyShip targetShip) {
        super(x, y);

        xValues = new ShiftRegister<Double>(length, x);
        yValues = new ShiftRegister<Double>(length, y);

        target = targetShip;
    }

    /**
     * Getter function
     * 
     * @return the EnemyShip the Projectile will hit
     */
    public EnemyShip getTarget() {
        return target;
    }

    /**
     * Displays the Projectile on the screen
     * 
     * @param g the Graphics object to paint with
     */
    @Override
    public void paint(Graphics g) {
        // Draw.circle(g, x, y, 3, 0xFF0000FF);
        double perc = .90;
        GFX.line(g, xValues.get(), yValues.get(), x, y, 0xFF0000FF);
        GFX.line(g, ((1-perc)*xValues.get()+perc*x), ((1-perc)*yValues.get()+perc*y), x, y, 0xFFCC00FF);
    }

    /**
     * Notifies the Projectile of time passing, moves it towards its target
     * 
     * @return true if the Projectile has reached its target
     */
    @Override
    public boolean progress() {
        double xDist = target.getX() - x;
        double yDist = target.getY() - y;

        double vectDist = Math.sqrt(xDist * xDist + yDist * yDist);

        if (vectDist < velocity) {
            return true;
        }

        xDist /= vectDist;
        xDist *= velocity;
        yDist /= vectDist;
        yDist *= velocity;

        xValues.push(x);
        yValues.push(y);

        x += xDist;
        y += yDist;

        return false;
    }
}
