package zkp;

import java.io.Serializable;
import java.util.concurrent.ArrayBlockingQueue;

/**
 * A FIFO container with specific functions
 * 
 * @author zsmb
 * @param <T> the type of elements to store
 */
public class ShiftRegister<T> implements Serializable {

    private static final long serialVersionUID = 1640941915789613639L;

    /**
     * Stores the elements in the ShiftRegister
     */
    private ArrayBlockingQueue<T> queue;

    /**
     * ShiftRegister ctor, fills the register with the initializer element
     * 
     * @param size the number of elements the ShiftRegister can store
     * @param initElement the initial value of all elements in the ShiftRegister
     */
    public ShiftRegister(int size, T initElement) {
        queue = new ArrayBlockingQueue<T>(size);
        try {
            for (int i = 0; i < size; i++) {
                queue.put(initElement);
            }
        } catch (InterruptedException e) {
            /* Do nothing, this is never going to happen */
        }
    }

    /**
     * Pushes an element to the end of the ShiftRegister
     * 
     * @param newElement the element to put in the ShiftRegister
     * @return the first element that gets pushed out of the ShiftRegister
     */
    public T push(T newElement) {
        T temp = null;
        try {
            temp = queue.take();
            queue.put(newElement);
        } catch (InterruptedException e) {
            e.printStackTrace();
        }
        return temp;
    }

    /**
     * Returns the element on the front of the ShiftRegister without removing it
     * 
     * @return the first element in the ShiftRegister
     */
    public T get() {
        return queue.peek();
    }
}
