package zkp;

import java.awt.Graphics;

import zkp.GamePanel.ShipClass;

/**
 * The small EnemyShip type spawned by ExplorerShips
 *
 * @author zsmb
 */
public class ShuttleShip extends EnemyShip {

    private static final long serialVersionUID = -7328644448004294676L;

    private static final int radius = 4; // Class specific radius to set in the
                                         // base class

    /**
     * ShuttleShip ctor
     * 
     * @param gpa the containing GamePanel's interface for communication
     * @param x the x position to spawn the FighterShip in
     * @param y the y position to spawn the FighterShip in
     */
    public ShuttleShip(GamePanelAccessProvider gpa, double x, double y) {
        super(gpa, radius, x, y);
        setWord(gpa.getWord(ShipClass.Shuttle));
        this.yVelocity = gpa.getUnitSpeed();
        this.xVelocity = gpa.getHorizontalCollisionCourseSpeed(this);
    }

    /**
     * Displays the ShuttleShip on the screen
     * 
     * @param g the Graphics object to paint with
     */
    @Override
    public void paint(Graphics g) {
        GFX.circle(g, x, y, radius, 0x00FFDDFF);
        paintText(g, -radius, 4);
    }

    /**
     * Getter function to determine the EnemyShip's type
     * 
     * @return ShipClass.ShuttleShip
     */
    @Override
    public ShipClass getShipClass() {
        return ShipClass.Shuttle;
    }

}
