package zkp;

import java.awt.Graphics;

import zkp.GamePanel.ShipClass;

/**
 * The most common EnemyShip of the game
 *
 * @author zsmb
 */
public class SimpleShip extends EnemyShip {

    private static final long serialVersionUID = -3251851596905926929L;

    private static final int radius = 8; // Class specific radius to set in the
                                         // base class

    /**
     * SimpleShip ctor
     * 
     * @param gpa the containing GamePanel's interface for communication
     */
    public SimpleShip(GamePanelAccessProvider gpa) {
        super(gpa, radius);
        setWord(gpa.getWord(ShipClass.Simple));
        this.yVelocity = gpa.getUnitSpeed() * 1;
    }

    /**
     * Getter function to determine the EnemyShip's type
     * 
     * @return ShipClass.Simple
     */
    @Override
    public ShipClass getShipClass() {
        return ShipClass.Simple;
    }

    /**
     * Displays the SimpleShip on the screen
     * 
     * @param g the Graphics object to use for drawing
     */
    @Override
    public void paint(Graphics g) {
        GFX.circle(g, x, y, radius, 0xFFDD00FF);
        paintText(g, -radius, 3);
    }

    /**
     * SimpleShips change to a collision course towards the PlayerShip when they get near
     * enough
     */
    private boolean onCollisionCourse = false;

    /**
     * Notifies SimpleShip of time passing, moves it forward
     */
    @Override
    public boolean progress() {
        if (!onCollisionCourse && gpa.getDistanceLeft(this) < 300) {
            onCollisionCourse = true;
            this.xVelocity = gpa.getHorizontalCollisionCourseSpeed(this);
        }
        return super.progress();
    }

}
